#
# spec file for package perl-PkgConfig
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-PkgConfig
Version:        0.25026
Release:        1.6
%define cpan_name PkgConfig
Summary:        Pure-Perl Core-Only replacement for pkg-config
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/P/PL/PLICEASE/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::More) >= 0.94
Requires:       perl(Test::More) >= 0.94
%{perl_requires}

%description
'PkgConfig' provides a pure-perl, core-only replacement for the
'pkg-config' utility.

This is not a description of the uses of 'pkg-config' but rather a
description of the differences between the C version and the Perl one.

While 'pkg-config' is a compiled binary linked with glib, the pure-perl
version has no such requirement, and will run wherever Perl ( >= 5.6 )
does.

The main supported options are the common '--libs', '--cflags', '--static',
'--exists' and '--modversion'.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes ignore.txt PkgConfig.kpf README README.win32
%license LICENSE

%changelog
* Thu Nov 12 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.25026
  see /usr/share/doc/packages/perl-PkgConfig/Changes
  0.25026 2020-11-11 03:32:17 -0700
  - Handle spaces in Perl and PkgConfig.pm path (gh#47, gh#52)
  - Fixed bug where --print-errors and --silence-errors were backwards,
    and the default was wrong (gh#53, gh#54, SLAFFAN++)
* Mon Jul 20 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.24026
  see /usr/share/doc/packages/perl-PkgConfig/Changes
  0.24026 2020-07-19 06:17:28 -0600
  - Fixed path on FreeBSD to use te modern defaults (gh#49, tomhukins++)
* Thu Nov  8 2018 Stephan Kulow <coolo@suse.com>
- updated to 0.23026
  see /usr/share/doc/packages/perl-PkgConfig/Changes
  0.23026 2018-10-15 05:31:23 -0400
  - Fixed only used once warning (gh#45, gh#46 Ari Jolma++)
* Wed Sep 19 2018 Stephan Kulow <coolo@suse.com>
- updated to 0.22026
  see /usr/share/doc/packages/perl-PkgConfig/Changes
* Sat Aug 18 2018 coolo@suse.com
- updated to 0.21026
  see /usr/share/doc/packages/perl-PkgConfig/Changes
  0.21026 2018-08-15
  - promote to production
  0.20026_01 2018-08-15
  - Fix bug where Strawberry Perl PAR::Packer packed PkgConfig.pm
    could die on startup (gh#45, gh#44 SLAFFAN++)
* Tue Jan  9 2018 coolo@suse.com
- updated to 0.19026
  see /usr/share/doc/packages/perl-PkgConfig/Changes
  0.19026 2017-11-21
  - Fix requirements for optional Perl::MinimumVersion test
* Wed Nov 22 2017 coolo@suse.com
- updated to 0.18026
  see /usr/share/doc/packages/perl-PkgConfig/Changes
  0.18026 2017-11-21
  - Add support for Slackware 64bit
* Tue Sep 19 2017 coolo@suse.com
- updated to 0.17026
  see /usr/share/doc/packages/perl-PkgConfig/Changes
  0.17026 2017-09-18
  - --modversion does not require dependencies
* Fri Mar 24 2017 coolo@suse.com
- updated to 0.16026
  see /usr/share/doc/packages/perl-PkgConfig/Changes
  0.16026 2017-03-23
  - Fix for Perl 5.25.11+ where '.' is not in @INC
* Sat Mar 11 2017 coolo@suse.com
- updated to 0.15026
  see /usr/share/doc/packages/perl-PkgConfig/Changes
  0.15026 2017-01-26
  - New release with fixes to META.json
* Sat Feb 25 2017 coolo@suse.com
- updated to 0.14026
  see /usr/share/doc/packages/perl-PkgConfig/Changes
* Mon May 23 2016 coolo@suse.com
- updated to 0.12026
  see /usr/share/doc/packages/perl-PkgConfig/Changes
  0.12026
  - Updated project URLs in README
  - Spelling fixes in various documentation files
  - Support for MSYS2
* Tue Jan 26 2016 coolo@suse.com
- updated to 0.11026
  see /usr/share/doc/packages/perl-PkgConfig/Changes
* Wed Jan 13 2016 coolo@suse.com
- updated to 0.10026
  see /usr/share/doc/packages/perl-PkgConfig/Changes
  0.10026 2015-01-08
  - promote to production
  0.09026_02 2016-01-07
  - Test and development changes only.  No functional or
    bug fixes to PkgConfig.pm itself.
  0.09026_01 2016-01-05
  - Remove use of flock
    It isn't portable and was causing hang/failures on NFS
  - Add --short-errors option
* Fri Apr 24 2015 coolo@suse.com
- initial package $version
  * created by $NAME $VERSION
